do
local Prefs = import('/lua/user/prefs.lua')
local options = Prefs.GetFromCurrentProfile('options')
local reclaimedTotalsMass = false
local reclaimedTotalsEnergy = false
local TextLine02 = false
local TextLine03 = false

if options.gui_display_reclaim_totals == 1 then
function _BeatFunction()
    local econData = GetEconomyTotals()
    local simFrequency = GetSimTicksPerSecond()
-- fetch & format reclaim values
    reclaimedTotalsMass = math.ceil(econData.reclaimed.MASS)
    reclaimedTotalsEnergy = math.ceil(econData.reclaimed.ENERGY)

    local function DisplayEconData(controls, tableID, viewPref)
        local function FormatRateString(RateVal, StoredVal, IncomeAvg, ActualAvg, RequestedAvg)
-- expanded display to 8 digits
            local retRateStr = string.format('%+d', math.min(math.max(RateVal, -99999999), 99999999))
            local retEffVal = 0
            if RequestedAvg == 0 then
                retEffVal = math.ceil(IncomeAvg) * 100
            else
                if StoredVal > 0.5 then
                    retEffVal = math.ceil( (IncomeAvg / ActualAvg) * 100 )
                else
                    retEffVal = math.ceil( (IncomeAvg / RequestedAvg) * 100 )
                end
            end
            return retRateStr, retEffVal
        end

        local maxStorageVal = econData["maxStorage"][tableID]
        local storedVal = econData["stored"][tableID]
        local incomeVal = econData["income"][tableID]
        local lastRequestedVal = econData["lastUseRequested"][tableID]
        local lastActualVal = econData["lastUseActual"][tableID]
-- expanded display to 8 digits
        local requestedAvg = math.min(lastRequestedVal * simFrequency, 99999999)
        local actualAvg = math.min(lastActualVal * simFrequency, 99999999)
        local incomeAvg = math.min(incomeVal * simFrequency, 99999999)

        controls.storageBar:SetRange(0, maxStorageVal)
        controls.storageBar:SetValue(storedVal)
        controls.curStorage:SetText(math.ceil(storedVal))
        controls.maxStorage:SetText(math.ceil(maxStorageVal))


        controls.income:SetText(string.format("+%d", math.ceil(incomeAvg)))
        if storedVal > 0.5 then
            controls.expense:SetText(string.format("-%d", math.ceil(actualAvg)))
        else
            controls.expense:SetText(string.format("-%d", math.ceil(requestedAvg)))
        end

        local rateVal = 0
        if storedVal > 0.5 then
            rateVal = math.ceil(incomeAvg - actualAvg)
        else
            rateVal = math.ceil(incomeAvg - requestedAvg)
        end

        local rateStr, effVal = FormatRateString(rateVal, storedVal, incomeAvg, actualAvg, requestedAvg)
        -- CHOOSE RATE or EFFICIENCY STRING
        if States[viewPref] == 2 then
            controls.rate:SetText(string.format("%d%%", math.min(effVal, 100)))
        else
            controls.rate:SetText(string.format("%+s", rateStr))
        end
        -- SET RATE/EFFICIENCY COLOR
        local rateColor
        if rateVal < 0 then
            if storedVal > 0 then
                rateColor = 'yellow'
            else
                rateColor = 'red'
            end
        else
            rateColor = 'ffb7e75f'
        end
        controls.rate:SetColor(rateColor)

        -- ECONOMY WARNINGS
        if Prefs.GetOption('econ_warnings') and UIState then
            if storedVal / maxStorageVal < .2 then
                if effVal < 25 then
                    controls.warningBG:SetToState('red')
                elseif effVal < 75 then
                    controls.warningBG:SetToState('yellow')
                elseif effVal > 100 then
                    controls.warningBG:SetToState('hide')
                end
            else
                controls.warningBG:SetToState('hide')
            end
        else
            controls.warningBG:SetToState('hide')
        end
    end
    DisplayEconData(GUI.mass, 'MASS', 'massViewState')
    DisplayEconData(GUI.energy, 'ENERGY', 'energyViewState')

-- display reclaim values
        TextLine02:SetText(reclaimedTotalsMass)
        TextLine03:SetText(reclaimedTotalsEnergy)

end

--display additional ui
    function CreateExtraUI()
        ecostats = Bitmap(GetFrame(0))
        ecostats:SetTexture('/textures/ui/common/game/economic-overlay/econ_bmp_m.dds')
        ecostats.Depth:Set(99)
        LayoutHelpers.AtLeftTopIn(ecostats, GetFrame(0), 340, 8)
        ecostats.Height:Set(36)
        ecostats.Width:Set(80)
        ecostats:DisableHitTest(true)
        local TextLine01 = UIUtil.CreateText(ecostats, 'reclaimed', 10, UIUtil.bodyFont)
        LayoutHelpers.CenteredAbove(TextLine01, ecostats, -12)
        TextLine02 = UIUtil.CreateText(ecostats, '', 10, UIUtil.bodyFont)
        TextLine02:SetColor('FFB8F400')
        LayoutHelpers.AtRightTopIn(TextLine02, ecostats, 4, 10)
        TextLine03 = UIUtil.CreateText(ecostats, '', 10, UIUtil.bodyFont)
        TextLine03:SetColor('FFF8C000')
        TextLine01:DisableHitTest(true)
        TextLine02:DisableHitTest(true)
        TextLine03:DisableHitTest(true)
        LayoutHelpers.AtRightTopIn(TextLine03, ecostats, 4, 20)
    end

    local OldCreateUI = CreateUI
    function CreateUI()
        OldCreateUI()
        CreateExtraUI()
    end
end

end